@@ -1,22 +1,28 @@
 use anyhow::Result;
-use solana_shadow::{BlockchainShadow, Network};
+use solana_shadow::{BlockchainShadow, SyncOptions};
 use std::time::Duration;
 use tracing_subscriber::EnvFilter;
 
-#[tokio::main]
-async fn main() -> Result<()> {
+fn configure_logging() {
   tracing_subscriber::fmt::Subscriber::builder()
     .with_writer(std::io::stdout)
-    .with_env_filter(EnvFilter::try_from_default_env()?)
+    .with_env_filter(
+      EnvFilter::try_from_default_env().unwrap_or(EnvFilter::new("info")),
+    )
     .init();
+}
+
+#[tokio::main]
+async fn main() -> Result<()> {
+  configure_logging();
 
   println!("this example will dump the values of all accounts owned by pyth program every 5 seconds");
   println!();
 
   // this is the prog id that owns all pyth oracles on mainnet
   let prog = "FsJ3A3u2vn5cTVofAjvy6y5kwABJAqYWpe4975bi2epH".parse()?;
-  let network = Network::Mainnet;
-  let local = BlockchainShadow::new_for_program(&prog, network).await?;
+  let local =
+    BlockchainShadow::new_for_program(&prog, SyncOptions::default()).await?;
 
   for _ in 0.. {
     local.for_each_account(|pubkey, account| {
